# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from typing import Any, Optional, TYPE_CHECKING

from msrest import Deserializer, Serializer

from azure.mgmt.core import AsyncARMPipelineClient
from azure.profiles import KnownProfiles, ProfileDefinition
from azure.profiles.multiapiclient import MultiApiClientMixin

from ._configuration import AzureMachineLearningWorkspacesConfiguration

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from azure.core.credentials import TokenCredential
    from azure.core.credentials_async import AsyncTokenCredential

class _SDKClient(object):
    def __init__(self, *args, **kwargs):
        """This is a fake class to support current implemetation of MultiApiClientMixin."
        Will be removed in final version of multiapi azure-core based client
        """
        pass

class AzureMachineLearningWorkspaces(MultiApiClientMixin, _SDKClient):
    """These APIs allow end users to operate on Azure Machine Learning Workspace resources.

    This ready contains multiple API versions, to help you deal with all of the Azure clouds
    (Azure Stack, Azure Government, Azure China, etc.).
    By default, it uses the latest API version available on public Azure.
    For production, you should stick to a particular api-version and/or profile.
    The profile sets a mapping between an operation group and its API version.
    The api-version parameter sets the default API version if the operation
    group is not described in the profile.

    :param credential: Credential needed for the client to connect to Azure.
    :type credential: ~azure.core.credentials_async.AsyncTokenCredential
    :param subscription_id: The ID of the target subscription.
    :type subscription_id: str
    :param api_version: API version to use if no profile is provided, or if missing in profile.
    :type api_version: str
    :param base_url: Service URL
    :type base_url: str
    :param profile: A profile definition, from KnownProfiles to dict.
    :type profile: azure.profiles.KnownProfiles
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no Retry-After header is present.
    """

    DEFAULT_API_VERSION = '2022-10-01'
    _PROFILE_TAG = "azure.mgmt.machinelearningservices.AzureMachineLearningWorkspaces"
    LATEST_PROFILE = ProfileDefinition({
        _PROFILE_TAG: {
            None: DEFAULT_API_VERSION,
            'assets': '1.0.0',
            'async_operations': 'v1.0',
            'batch_job_deployment': '2020-09-01-dataplanepreview',
            'batch_job_endpoint': '2020-09-01-dataplanepreview',
            'data_call': '1.5.0',
            'data_container': '1.5.0',
            'data_references': '2021-10-01-dataplanepreview',
            'data_version': '1.5.0',
            'dataset_containers': '2021-10-01',
            'dataset_controller_v2': '1.5.0',
            'dataset_v2': '1.5.0',
            'dataset_versions': '2021-10-01',
            'datasets_v1': '1.5.0',
            'delete': 'v1.0',
            'events': 'v1.0',
            'experiments': 'v1.0',
            'extensive_model': '1.0.0',
            'get_operation_status': '1.5.0',
            'metric': 'v1.0',
            'migration': '1.0.0',
            'models': '1.0.0',
            'registry_management_non_workspace': 'v1.0',
            'resource_management_asset_reference': '2021-10-01-dataplanepreview',
            'run': 'v1.0',
            'run_artifacts': 'v1.0',
            'runs': 'v1.0',
            'spans': 'v1.0',
            'temporary_data_references': '2021-10-01-dataplanepreview',
        }},
        _PROFILE_TAG + " latest"
    )

    def __init__(
        self,
        credential: "AsyncTokenCredential",
        subscription_id: str,
        api_version: Optional[str] = None,
        base_url: str = "https://management.azure.com",
        profile: KnownProfiles = KnownProfiles.default,
        **kwargs  # type: Any
    ) -> None:
        self._config = AzureMachineLearningWorkspacesConfiguration(credential, subscription_id, **kwargs)
        self._client = AsyncARMPipelineClient(base_url=base_url, config=self._config, **kwargs)
        super(AzureMachineLearningWorkspaces, self).__init__(
            api_version=api_version,
            profile=profile
        )

    @classmethod
    def _models_dict(cls, api_version):
        return {k: v for k, v in cls.models(api_version).__dict__.items() if isinstance(v, type)}

    @classmethod
    def models(cls, api_version=DEFAULT_API_VERSION):
        """Module depends on the API version:

           * 1.5.0: :mod:`dataset_dataplane.models<azure.mgmt.machinelearningservices.dataset_dataplane.models>`
           * 1.0.0: :mod:`model_dataplane.models<azure.mgmt.machinelearningservices.model_dataplane.models>`
           * v1.0: :mod:`registry_discovery.models<azure.mgmt.machinelearningservices.registry_discovery.models>`
           * v1.0: :mod:`runhistory.models<azure.mgmt.machinelearningservices.runhistory.models>`
           * 2020-09-01-dataplanepreview: :mod:`v2020_09_01_dataplanepreview.models<azure.mgmt.machinelearningservices.v2020_09_01_dataplanepreview.models>`
           * 2021-10-01: :mod:`v2021_10_01.models<azure.mgmt.machinelearningservices.v2021_10_01.models>`
           * 2021-10-01-dataplanepreview: :mod:`v2021_10_01_dataplanepreview.models<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.models>`
           * 2022-01-01-preview: :mod:`v2022_01_01_preview.models<azure.mgmt.machinelearningservices.v2022_01_01_preview.models>`
           * 2022-02-01-preview: :mod:`v2022_02_01_preview.models<azure.mgmt.machinelearningservices.v2022_02_01_preview.models>`
           * 2022-05-01: :mod:`v2022_05_01.models<azure.mgmt.machinelearningservices.v2022_05_01.models>`
           * 2022-06-01-preview: :mod:`v2022_06_01_preview.models<azure.mgmt.machinelearningservices.v2022_06_01_preview.models>`
           * 2022-10-01: :mod:`v2022_10_01.models<azure.mgmt.machinelearningservices.v2022_10_01.models>`
           * 2022-10-01-preview: :mod:`v2022_10_01_preview.models<azure.mgmt.machinelearningservices.v2022_10_01_preview.models>`
        """
        if api_version == '1.5.0':
            from ..dataset_dataplane import models
            return models
        elif api_version == '1.0.0':
            from ..model_dataplane import models
            return models
        elif api_version == 'v1.0':
            from ..registry_discovery import models
            return models
        elif api_version == 'v1.0':
            from ..runhistory import models
            return models
        elif api_version == '2020-09-01-dataplanepreview':
            from ..v2020_09_01_dataplanepreview import models
            return models
        elif api_version == '2021-10-01':
            from ..v2021_10_01 import models
            return models
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview import models
            return models
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview import models
            return models
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview import models
            return models
        elif api_version == '2022-05-01':
            from ..v2022_05_01 import models
            return models
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview import models
            return models
        elif api_version == '2022-10-01':
            from ..v2022_10_01 import models
            return models
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview import models
            return models
        raise ValueError("API version {} is not available".format(api_version))

    @property
    def assets(self):
        """Instance depends on the API version:

           * 1.0.0: :class:`AssetsOperations<azure.mgmt.machinelearningservices.model_dataplane.aio.operations.AssetsOperations>`
        """
        api_version = self._get_api_version('assets')
        if api_version == '1.0.0':
            from ..model_dataplane.aio.operations import AssetsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'assets'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def async_operations(self):
        """Instance depends on the API version:

           * v1.0: :class:`AsyncOperationsOperations<azure.mgmt.machinelearningservices.registry_discovery.aio.operations.AsyncOperationsOperations>`
        """
        api_version = self._get_api_version('async_operations')
        if api_version == 'v1.0':
            from ..registry_discovery.aio.operations import AsyncOperationsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'async_operations'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def batch_deployments(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.BatchDeploymentsOperations>`
           * 2022-02-01-preview: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.BatchDeploymentsOperations>`
           * 2022-05-01: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.BatchDeploymentsOperations>`
           * 2022-06-01-preview: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.BatchDeploymentsOperations>`
           * 2022-10-01: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.BatchDeploymentsOperations>`
           * 2022-10-01-preview: :class:`BatchDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.BatchDeploymentsOperations>`
        """
        api_version = self._get_api_version('batch_deployments')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import BatchDeploymentsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import BatchDeploymentsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import BatchDeploymentsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import BatchDeploymentsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import BatchDeploymentsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import BatchDeploymentsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'batch_deployments'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def batch_endpoints(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.BatchEndpointsOperations>`
           * 2022-02-01-preview: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.BatchEndpointsOperations>`
           * 2022-05-01: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.BatchEndpointsOperations>`
           * 2022-06-01-preview: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.BatchEndpointsOperations>`
           * 2022-10-01: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.BatchEndpointsOperations>`
           * 2022-10-01-preview: :class:`BatchEndpointsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.BatchEndpointsOperations>`
        """
        api_version = self._get_api_version('batch_endpoints')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import BatchEndpointsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import BatchEndpointsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import BatchEndpointsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import BatchEndpointsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import BatchEndpointsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import BatchEndpointsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'batch_endpoints'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def batch_job_deployment(self):
        """Instance depends on the API version:

           * 2020-09-01-dataplanepreview: :class:`BatchJobDeploymentOperations<azure.mgmt.machinelearningservices.v2020_09_01_dataplanepreview.aio.operations.BatchJobDeploymentOperations>`
        """
        api_version = self._get_api_version('batch_job_deployment')
        if api_version == '2020-09-01-dataplanepreview':
            from ..v2020_09_01_dataplanepreview.aio.operations import BatchJobDeploymentOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'batch_job_deployment'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def batch_job_endpoint(self):
        """Instance depends on the API version:

           * 2020-09-01-dataplanepreview: :class:`BatchJobEndpointOperations<azure.mgmt.machinelearningservices.v2020_09_01_dataplanepreview.aio.operations.BatchJobEndpointOperations>`
        """
        api_version = self._get_api_version('batch_job_endpoint')
        if api_version == '2020-09-01-dataplanepreview':
            from ..v2020_09_01_dataplanepreview.aio.operations import BatchJobEndpointOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'batch_job_endpoint'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def code_containers(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.CodeContainersOperations>`
           * 2021-10-01-dataplanepreview: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.CodeContainersOperations>`
           * 2022-02-01-preview: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.CodeContainersOperations>`
           * 2022-05-01: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.CodeContainersOperations>`
           * 2022-06-01-preview: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.CodeContainersOperations>`
           * 2022-10-01: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.CodeContainersOperations>`
           * 2022-10-01-preview: :class:`CodeContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.CodeContainersOperations>`
        """
        api_version = self._get_api_version('code_containers')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import CodeContainersOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import CodeContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'code_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def code_versions(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.CodeVersionsOperations>`
           * 2021-10-01-dataplanepreview: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.CodeVersionsOperations>`
           * 2022-02-01-preview: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.CodeVersionsOperations>`
           * 2022-05-01: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.CodeVersionsOperations>`
           * 2022-06-01-preview: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.CodeVersionsOperations>`
           * 2022-10-01: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.CodeVersionsOperations>`
           * 2022-10-01-preview: :class:`CodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.CodeVersionsOperations>`
        """
        api_version = self._get_api_version('code_versions')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import CodeVersionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import CodeVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'code_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def component_containers(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.ComponentContainersOperations>`
           * 2021-10-01-dataplanepreview: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.ComponentContainersOperations>`
           * 2022-02-01-preview: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.ComponentContainersOperations>`
           * 2022-05-01: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.ComponentContainersOperations>`
           * 2022-06-01-preview: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.ComponentContainersOperations>`
           * 2022-10-01: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.ComponentContainersOperations>`
           * 2022-10-01-preview: :class:`ComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.ComponentContainersOperations>`
        """
        api_version = self._get_api_version('component_containers')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import ComponentContainersOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import ComponentContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'component_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def component_versions(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.ComponentVersionsOperations>`
           * 2021-10-01-dataplanepreview: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.ComponentVersionsOperations>`
           * 2022-02-01-preview: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.ComponentVersionsOperations>`
           * 2022-05-01: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.ComponentVersionsOperations>`
           * 2022-06-01-preview: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.ComponentVersionsOperations>`
           * 2022-10-01: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.ComponentVersionsOperations>`
           * 2022-10-01-preview: :class:`ComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.ComponentVersionsOperations>`
        """
        api_version = self._get_api_version('component_versions')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import ComponentVersionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import ComponentVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'component_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def compute(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`ComputeOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.ComputeOperations>`
           * 2022-01-01-preview: :class:`ComputeOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.ComputeOperations>`
           * 2022-05-01: :class:`ComputeOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.ComputeOperations>`
           * 2022-10-01: :class:`ComputeOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.ComputeOperations>`
           * 2022-10-01-preview: :class:`ComputeOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.ComputeOperations>`
        """
        api_version = self._get_api_version('compute')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import ComputeOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import ComputeOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import ComputeOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import ComputeOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import ComputeOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'compute'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_call(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DataCallOperations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DataCallOperations>`
        """
        api_version = self._get_api_version('data_call')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DataCallOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_call'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_container(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DataContainerOperations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DataContainerOperations>`
        """
        api_version = self._get_api_version('data_container')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DataContainerOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_container'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_containers(self):
        """Instance depends on the API version:

           * 2021-10-01-dataplanepreview: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.DataContainersOperations>`
           * 2022-02-01-preview: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.DataContainersOperations>`
           * 2022-05-01: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.DataContainersOperations>`
           * 2022-06-01-preview: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.DataContainersOperations>`
           * 2022-10-01: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.DataContainersOperations>`
           * 2022-10-01-preview: :class:`DataContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.DataContainersOperations>`
        """
        api_version = self._get_api_version('data_containers')
        if api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import DataContainersOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import DataContainersOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import DataContainersOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import DataContainersOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import DataContainersOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import DataContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_references(self):
        """Instance depends on the API version:

           * 2021-10-01-dataplanepreview: :class:`DataReferencesOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.DataReferencesOperations>`
        """
        api_version = self._get_api_version('data_references')
        if api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import DataReferencesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_references'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_version(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DataVersionOperations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DataVersionOperations>`
        """
        api_version = self._get_api_version('data_version')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DataVersionOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_version'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def data_versions(self):
        """Instance depends on the API version:

           * 2021-10-01-dataplanepreview: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.DataVersionsOperations>`
           * 2022-02-01-preview: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.DataVersionsOperations>`
           * 2022-05-01: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.DataVersionsOperations>`
           * 2022-06-01-preview: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.DataVersionsOperations>`
           * 2022-10-01: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.DataVersionsOperations>`
           * 2022-10-01-preview: :class:`DataVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.DataVersionsOperations>`
        """
        api_version = self._get_api_version('data_versions')
        if api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import DataVersionsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import DataVersionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import DataVersionsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import DataVersionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import DataVersionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import DataVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'data_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def dataset_containers(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`DatasetContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.DatasetContainersOperations>`
        """
        api_version = self._get_api_version('dataset_containers')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import DatasetContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'dataset_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def dataset_controller_v2(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DatasetControllerV2Operations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DatasetControllerV2Operations>`
        """
        api_version = self._get_api_version('dataset_controller_v2')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DatasetControllerV2Operations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'dataset_controller_v2'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def dataset_v2(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DatasetV2Operations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DatasetV2Operations>`
        """
        api_version = self._get_api_version('dataset_v2')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DatasetV2Operations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'dataset_v2'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def dataset_versions(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`DatasetVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.DatasetVersionsOperations>`
        """
        api_version = self._get_api_version('dataset_versions')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import DatasetVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'dataset_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def datasets_v1(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DatasetsV1Operations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DatasetsV1Operations>`
        """
        api_version = self._get_api_version('datasets_v1')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DatasetsV1Operations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'datasets_v1'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def datastores(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.DatastoresOperations>`
           * 2022-02-01-preview: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.DatastoresOperations>`
           * 2022-05-01: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.DatastoresOperations>`
           * 2022-06-01-preview: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.DatastoresOperations>`
           * 2022-10-01: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.DatastoresOperations>`
           * 2022-10-01-preview: :class:`DatastoresOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.DatastoresOperations>`
        """
        api_version = self._get_api_version('datastores')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import DatastoresOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import DatastoresOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import DatastoresOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import DatastoresOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import DatastoresOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import DatastoresOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'datastores'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def delete(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`DeleteOperations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.DeleteOperations>`
           * v1.0: :class:`DeleteOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.DeleteOperations>`
        """
        api_version = self._get_api_version('delete')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import DeleteOperations as OperationClass
        elif api_version == 'v1.0':
            from ..runhistory.aio.operations import DeleteOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'delete'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def environment_containers(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.EnvironmentContainersOperations>`
           * 2021-10-01-dataplanepreview: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.EnvironmentContainersOperations>`
           * 2022-02-01-preview: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.EnvironmentContainersOperations>`
           * 2022-05-01: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.EnvironmentContainersOperations>`
           * 2022-06-01-preview: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.EnvironmentContainersOperations>`
           * 2022-10-01: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.EnvironmentContainersOperations>`
           * 2022-10-01-preview: :class:`EnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.EnvironmentContainersOperations>`
        """
        api_version = self._get_api_version('environment_containers')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import EnvironmentContainersOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import EnvironmentContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'environment_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def environment_versions(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.EnvironmentVersionsOperations>`
           * 2021-10-01-dataplanepreview: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.EnvironmentVersionsOperations>`
           * 2022-02-01-preview: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.EnvironmentVersionsOperations>`
           * 2022-05-01: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.EnvironmentVersionsOperations>`
           * 2022-06-01-preview: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.EnvironmentVersionsOperations>`
           * 2022-10-01: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.EnvironmentVersionsOperations>`
           * 2022-10-01-preview: :class:`EnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.EnvironmentVersionsOperations>`
        """
        api_version = self._get_api_version('environment_versions')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import EnvironmentVersionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import EnvironmentVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'environment_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def events(self):
        """Instance depends on the API version:

           * v1.0: :class:`EventsOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.EventsOperations>`
        """
        api_version = self._get_api_version('events')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import EventsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'events'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def experiments(self):
        """Instance depends on the API version:

           * v1.0: :class:`ExperimentsOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.ExperimentsOperations>`
        """
        api_version = self._get_api_version('experiments')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import ExperimentsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'experiments'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def extensive_model(self):
        """Instance depends on the API version:

           * 1.0.0: :class:`ExtensiveModelOperations<azure.mgmt.machinelearningservices.model_dataplane.aio.operations.ExtensiveModelOperations>`
        """
        api_version = self._get_api_version('extensive_model')
        if api_version == '1.0.0':
            from ..model_dataplane.aio.operations import ExtensiveModelOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'extensive_model'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def get_operation_status(self):
        """Instance depends on the API version:

           * 1.5.0: :class:`GetOperationStatusOperations<azure.mgmt.machinelearningservices.dataset_dataplane.aio.operations.GetOperationStatusOperations>`
        """
        api_version = self._get_api_version('get_operation_status')
        if api_version == '1.5.0':
            from ..dataset_dataplane.aio.operations import GetOperationStatusOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'get_operation_status'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def jobs(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.JobsOperations>`
           * 2022-02-01-preview: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.JobsOperations>`
           * 2022-05-01: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.JobsOperations>`
           * 2022-06-01-preview: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.JobsOperations>`
           * 2022-10-01: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.JobsOperations>`
           * 2022-10-01-preview: :class:`JobsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.JobsOperations>`
        """
        api_version = self._get_api_version('jobs')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import JobsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import JobsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import JobsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import JobsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import JobsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import JobsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'jobs'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def labeling_jobs(self):
        """Instance depends on the API version:

           * 2022-06-01-preview: :class:`LabelingJobsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.LabelingJobsOperations>`
           * 2022-10-01-preview: :class:`LabelingJobsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.LabelingJobsOperations>`
        """
        api_version = self._get_api_version('labeling_jobs')
        if api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import LabelingJobsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import LabelingJobsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'labeling_jobs'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def metric(self):
        """Instance depends on the API version:

           * v1.0: :class:`MetricOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.MetricOperations>`
        """
        api_version = self._get_api_version('metric')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import MetricOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'metric'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def migration(self):
        """Instance depends on the API version:

           * 1.0.0: :class:`MigrationOperations<azure.mgmt.machinelearningservices.model_dataplane.aio.operations.MigrationOperations>`
        """
        api_version = self._get_api_version('migration')
        if api_version == '1.0.0':
            from ..model_dataplane.aio.operations import MigrationOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'migration'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def model_containers(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.ModelContainersOperations>`
           * 2021-10-01-dataplanepreview: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.ModelContainersOperations>`
           * 2022-02-01-preview: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.ModelContainersOperations>`
           * 2022-05-01: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.ModelContainersOperations>`
           * 2022-06-01-preview: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.ModelContainersOperations>`
           * 2022-10-01: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.ModelContainersOperations>`
           * 2022-10-01-preview: :class:`ModelContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.ModelContainersOperations>`
        """
        api_version = self._get_api_version('model_containers')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import ModelContainersOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import ModelContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'model_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def model_versions(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.ModelVersionsOperations>`
           * 2021-10-01-dataplanepreview: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.ModelVersionsOperations>`
           * 2022-02-01-preview: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.ModelVersionsOperations>`
           * 2022-05-01: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.ModelVersionsOperations>`
           * 2022-06-01-preview: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.ModelVersionsOperations>`
           * 2022-10-01: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.ModelVersionsOperations>`
           * 2022-10-01-preview: :class:`ModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.ModelVersionsOperations>`
        """
        api_version = self._get_api_version('model_versions')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import ModelVersionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import ModelVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'model_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def models(self):
        """Instance depends on the API version:

           * 1.0.0: :class:`ModelsOperations<azure.mgmt.machinelearningservices.model_dataplane.aio.operations.ModelsOperations>`
        """
        api_version = self._get_api_version('models')
        if api_version == '1.0.0':
            from ..model_dataplane.aio.operations import ModelsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'models'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def online_deployments(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.OnlineDeploymentsOperations>`
           * 2022-02-01-preview: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.OnlineDeploymentsOperations>`
           * 2022-05-01: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.OnlineDeploymentsOperations>`
           * 2022-06-01-preview: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.OnlineDeploymentsOperations>`
           * 2022-10-01: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.OnlineDeploymentsOperations>`
           * 2022-10-01-preview: :class:`OnlineDeploymentsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.OnlineDeploymentsOperations>`
        """
        api_version = self._get_api_version('online_deployments')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import OnlineDeploymentsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import OnlineDeploymentsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import OnlineDeploymentsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import OnlineDeploymentsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import OnlineDeploymentsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import OnlineDeploymentsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'online_deployments'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def online_endpoints(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.OnlineEndpointsOperations>`
           * 2022-02-01-preview: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2022_02_01_preview.aio.operations.OnlineEndpointsOperations>`
           * 2022-05-01: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.OnlineEndpointsOperations>`
           * 2022-06-01-preview: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.OnlineEndpointsOperations>`
           * 2022-10-01: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.OnlineEndpointsOperations>`
           * 2022-10-01-preview: :class:`OnlineEndpointsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.OnlineEndpointsOperations>`
        """
        api_version = self._get_api_version('online_endpoints')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import OnlineEndpointsOperations as OperationClass
        elif api_version == '2022-02-01-preview':
            from ..v2022_02_01_preview.aio.operations import OnlineEndpointsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import OnlineEndpointsOperations as OperationClass
        elif api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import OnlineEndpointsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import OnlineEndpointsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import OnlineEndpointsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'online_endpoints'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def operations(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`Operations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.Operations>`
           * 2022-01-01-preview: :class:`Operations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.Operations>`
           * 2022-05-01: :class:`Operations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.Operations>`
           * 2022-10-01: :class:`Operations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.Operations>`
           * 2022-10-01-preview: :class:`Operations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.Operations>`
        """
        api_version = self._get_api_version('operations')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import Operations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import Operations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import Operations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import Operations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import Operations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'operations'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def private_endpoint_connections(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`PrivateEndpointConnectionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.PrivateEndpointConnectionsOperations>`
           * 2022-01-01-preview: :class:`PrivateEndpointConnectionsOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.PrivateEndpointConnectionsOperations>`
           * 2022-05-01: :class:`PrivateEndpointConnectionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.PrivateEndpointConnectionsOperations>`
           * 2022-10-01: :class:`PrivateEndpointConnectionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.PrivateEndpointConnectionsOperations>`
           * 2022-10-01-preview: :class:`PrivateEndpointConnectionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.PrivateEndpointConnectionsOperations>`
        """
        api_version = self._get_api_version('private_endpoint_connections')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import PrivateEndpointConnectionsOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import PrivateEndpointConnectionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import PrivateEndpointConnectionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import PrivateEndpointConnectionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import PrivateEndpointConnectionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'private_endpoint_connections'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def private_link_resources(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`PrivateLinkResourcesOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.PrivateLinkResourcesOperations>`
           * 2022-01-01-preview: :class:`PrivateLinkResourcesOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.PrivateLinkResourcesOperations>`
           * 2022-05-01: :class:`PrivateLinkResourcesOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.PrivateLinkResourcesOperations>`
           * 2022-10-01: :class:`PrivateLinkResourcesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.PrivateLinkResourcesOperations>`
           * 2022-10-01-preview: :class:`PrivateLinkResourcesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.PrivateLinkResourcesOperations>`
        """
        api_version = self._get_api_version('private_link_resources')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import PrivateLinkResourcesOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import PrivateLinkResourcesOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import PrivateLinkResourcesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import PrivateLinkResourcesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import PrivateLinkResourcesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'private_link_resources'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def quotas(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`QuotasOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.QuotasOperations>`
           * 2022-01-01-preview: :class:`QuotasOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.QuotasOperations>`
           * 2022-05-01: :class:`QuotasOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.QuotasOperations>`
           * 2022-10-01: :class:`QuotasOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.QuotasOperations>`
           * 2022-10-01-preview: :class:`QuotasOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.QuotasOperations>`
        """
        api_version = self._get_api_version('quotas')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import QuotasOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import QuotasOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import QuotasOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import QuotasOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import QuotasOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'quotas'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registries(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistriesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistriesOperations>`
        """
        api_version = self._get_api_version('registries')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistriesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registries'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_code_containers(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryCodeContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryCodeContainersOperations>`
        """
        api_version = self._get_api_version('registry_code_containers')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryCodeContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_code_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_code_versions(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryCodeVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryCodeVersionsOperations>`
        """
        api_version = self._get_api_version('registry_code_versions')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryCodeVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_code_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_component_containers(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryComponentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryComponentContainersOperations>`
        """
        api_version = self._get_api_version('registry_component_containers')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryComponentContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_component_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_component_versions(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryComponentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryComponentVersionsOperations>`
        """
        api_version = self._get_api_version('registry_component_versions')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryComponentVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_component_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_environment_containers(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryEnvironmentContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryEnvironmentContainersOperations>`
        """
        api_version = self._get_api_version('registry_environment_containers')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryEnvironmentContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_environment_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_environment_versions(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryEnvironmentVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryEnvironmentVersionsOperations>`
        """
        api_version = self._get_api_version('registry_environment_versions')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryEnvironmentVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_environment_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_management_non_workspace(self):
        """Instance depends on the API version:

           * v1.0: :class:`RegistryManagementNonWorkspaceOperations<azure.mgmt.machinelearningservices.registry_discovery.aio.operations.RegistryManagementNonWorkspaceOperations>`
        """
        api_version = self._get_api_version('registry_management_non_workspace')
        if api_version == 'v1.0':
            from ..registry_discovery.aio.operations import RegistryManagementNonWorkspaceOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_management_non_workspace'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_model_containers(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryModelContainersOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryModelContainersOperations>`
        """
        api_version = self._get_api_version('registry_model_containers')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryModelContainersOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_model_containers'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def registry_model_versions(self):
        """Instance depends on the API version:

           * 2022-10-01-preview: :class:`RegistryModelVersionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.RegistryModelVersionsOperations>`
        """
        api_version = self._get_api_version('registry_model_versions')
        if api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import RegistryModelVersionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'registry_model_versions'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def resource_management_asset_reference(self):
        """Instance depends on the API version:

           * 2021-10-01-dataplanepreview: :class:`ResourceManagementAssetReferenceOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.ResourceManagementAssetReferenceOperations>`
        """
        api_version = self._get_api_version('resource_management_asset_reference')
        if api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import ResourceManagementAssetReferenceOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'resource_management_asset_reference'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def run(self):
        """Instance depends on the API version:

           * v1.0: :class:`RunOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.RunOperations>`
        """
        api_version = self._get_api_version('run')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import RunOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'run'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def run_artifacts(self):
        """Instance depends on the API version:

           * v1.0: :class:`RunArtifactsOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.RunArtifactsOperations>`
        """
        api_version = self._get_api_version('run_artifacts')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import RunArtifactsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'run_artifacts'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def runs(self):
        """Instance depends on the API version:

           * v1.0: :class:`RunsOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.RunsOperations>`
        """
        api_version = self._get_api_version('runs')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import RunsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'runs'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def schedules(self):
        """Instance depends on the API version:

           * 2022-06-01-preview: :class:`SchedulesOperations<azure.mgmt.machinelearningservices.v2022_06_01_preview.aio.operations.SchedulesOperations>`
           * 2022-10-01: :class:`SchedulesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.SchedulesOperations>`
           * 2022-10-01-preview: :class:`SchedulesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.SchedulesOperations>`
        """
        api_version = self._get_api_version('schedules')
        if api_version == '2022-06-01-preview':
            from ..v2022_06_01_preview.aio.operations import SchedulesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import SchedulesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import SchedulesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'schedules'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def spans(self):
        """Instance depends on the API version:

           * v1.0: :class:`SpansOperations<azure.mgmt.machinelearningservices.runhistory.aio.operations.SpansOperations>`
        """
        api_version = self._get_api_version('spans')
        if api_version == 'v1.0':
            from ..runhistory.aio.operations import SpansOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'spans'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def temporary_data_references(self):
        """Instance depends on the API version:

           * 2021-10-01-dataplanepreview: :class:`TemporaryDataReferencesOperations<azure.mgmt.machinelearningservices.v2021_10_01_dataplanepreview.aio.operations.TemporaryDataReferencesOperations>`
        """
        api_version = self._get_api_version('temporary_data_references')
        if api_version == '2021-10-01-dataplanepreview':
            from ..v2021_10_01_dataplanepreview.aio.operations import TemporaryDataReferencesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'temporary_data_references'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def usages(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`UsagesOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.UsagesOperations>`
           * 2022-01-01-preview: :class:`UsagesOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.UsagesOperations>`
           * 2022-05-01: :class:`UsagesOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.UsagesOperations>`
           * 2022-10-01: :class:`UsagesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.UsagesOperations>`
           * 2022-10-01-preview: :class:`UsagesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.UsagesOperations>`
        """
        api_version = self._get_api_version('usages')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import UsagesOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import UsagesOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import UsagesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import UsagesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import UsagesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'usages'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def virtual_machine_sizes(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`VirtualMachineSizesOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.VirtualMachineSizesOperations>`
           * 2022-01-01-preview: :class:`VirtualMachineSizesOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.VirtualMachineSizesOperations>`
           * 2022-05-01: :class:`VirtualMachineSizesOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.VirtualMachineSizesOperations>`
           * 2022-10-01: :class:`VirtualMachineSizesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.VirtualMachineSizesOperations>`
           * 2022-10-01-preview: :class:`VirtualMachineSizesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.VirtualMachineSizesOperations>`
        """
        api_version = self._get_api_version('virtual_machine_sizes')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import VirtualMachineSizesOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import VirtualMachineSizesOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import VirtualMachineSizesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import VirtualMachineSizesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import VirtualMachineSizesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'virtual_machine_sizes'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def workspace_connections(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`WorkspaceConnectionsOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.WorkspaceConnectionsOperations>`
           * 2022-01-01-preview: :class:`WorkspaceConnectionsOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.WorkspaceConnectionsOperations>`
           * 2022-05-01: :class:`WorkspaceConnectionsOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.WorkspaceConnectionsOperations>`
           * 2022-10-01: :class:`WorkspaceConnectionsOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.WorkspaceConnectionsOperations>`
           * 2022-10-01-preview: :class:`WorkspaceConnectionsOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.WorkspaceConnectionsOperations>`
        """
        api_version = self._get_api_version('workspace_connections')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import WorkspaceConnectionsOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import WorkspaceConnectionsOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import WorkspaceConnectionsOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import WorkspaceConnectionsOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import WorkspaceConnectionsOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'workspace_connections'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def workspace_features(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`WorkspaceFeaturesOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.WorkspaceFeaturesOperations>`
           * 2022-01-01-preview: :class:`WorkspaceFeaturesOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.WorkspaceFeaturesOperations>`
           * 2022-05-01: :class:`WorkspaceFeaturesOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.WorkspaceFeaturesOperations>`
           * 2022-10-01: :class:`WorkspaceFeaturesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.WorkspaceFeaturesOperations>`
           * 2022-10-01-preview: :class:`WorkspaceFeaturesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.WorkspaceFeaturesOperations>`
        """
        api_version = self._get_api_version('workspace_features')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import WorkspaceFeaturesOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import WorkspaceFeaturesOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import WorkspaceFeaturesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import WorkspaceFeaturesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import WorkspaceFeaturesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'workspace_features'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    @property
    def workspaces(self):
        """Instance depends on the API version:

           * 2021-10-01: :class:`WorkspacesOperations<azure.mgmt.machinelearningservices.v2021_10_01.aio.operations.WorkspacesOperations>`
           * 2022-01-01-preview: :class:`WorkspacesOperations<azure.mgmt.machinelearningservices.v2022_01_01_preview.aio.operations.WorkspacesOperations>`
           * 2022-05-01: :class:`WorkspacesOperations<azure.mgmt.machinelearningservices.v2022_05_01.aio.operations.WorkspacesOperations>`
           * 2022-10-01: :class:`WorkspacesOperations<azure.mgmt.machinelearningservices.v2022_10_01.aio.operations.WorkspacesOperations>`
           * 2022-10-01-preview: :class:`WorkspacesOperations<azure.mgmt.machinelearningservices.v2022_10_01_preview.aio.operations.WorkspacesOperations>`
        """
        api_version = self._get_api_version('workspaces')
        if api_version == '2021-10-01':
            from ..v2021_10_01.aio.operations import WorkspacesOperations as OperationClass
        elif api_version == '2022-01-01-preview':
            from ..v2022_01_01_preview.aio.operations import WorkspacesOperations as OperationClass
        elif api_version == '2022-05-01':
            from ..v2022_05_01.aio.operations import WorkspacesOperations as OperationClass
        elif api_version == '2022-10-01':
            from ..v2022_10_01.aio.operations import WorkspacesOperations as OperationClass
        elif api_version == '2022-10-01-preview':
            from ..v2022_10_01_preview.aio.operations import WorkspacesOperations as OperationClass
        else:
            raise ValueError("API version {} does not have operation group 'workspaces'".format(api_version))
        return OperationClass(self._client, self._config, Serializer(self._models_dict(api_version)), Deserializer(self._models_dict(api_version)))

    async def close(self):
        await self._client.close()
    async def __aenter__(self):
        await self._client.__aenter__()
        return self
    async def __aexit__(self, *exc_details):
        await self._client.__aexit__(*exc_details)



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: ml_samples_compute_configurations.py
DESCRIPTION:
    These samples demonstrate different ways to configure Compute.
USAGE:
    python ml_samples_compute_configurations.py

"""

import os
from random import randint

from azure.ai.ml import MLClient
from azure.core.exceptions import ResourceExistsError, ResourceNotFoundError
from azure.identity import DefaultAzureCredential


def handle_resource_exists_error(func):
    def wrapper(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except (ResourceExistsError, ResourceNotFoundError) as e:
            pass

    return wrapper


subscription_id = os.environ["AZURE_SUBSCRIPTION_ID"]
resource_group = os.environ["RESOURCE_GROUP_NAME"]
workspace_name = "test-ws1"
credential = DefaultAzureCredential()
ml_client = MLClient(credential, subscription_id, resource_group, workspace_name=workspace_name)

compute_name_1 = f"compute-{randint(1, 1000)}-sample"
compute_name_2 = f"compute-{randint(1, 1000)}-sample"
ci_name = f"ci-{randint(1, 1000)}-sample"


class ComputeConfigurationOptions(object):
    @handle_resource_exists_error
    def ml_compute_config_setup_0(self):
        # [START compute_instance]
        from azure.ai.ml.entities import ComputeInstance

        ci = ComputeInstance(
            name=ci_name,
            size="Standard_DS2_v2",
        )
        ml_client.compute.begin_create_or_update(ci)
        # [END compute_instance]

    @handle_resource_exists_error
    def ml_compute_config_setup_1(self):
        # [START compute_operations_get]
        cpu_cluster = ml_client.compute.get("cpu-cluster")
        # [END compute_operations_get]

        # [START load_compute]
        from azure.ai.ml import load_compute

        compute = load_compute(
            "../tests/test_configs/compute/compute-vm.yaml",
            params_override=[{"description": "loaded from compute-vm.yaml"}],
        )
        # [END load_compute]

        # [START compute_operations_list]
        compute_list = ml_client.compute.list(compute_type="AMLK8s")  # cspell:disable-line
        # [END compute_operations_list]

        # [START compute_operations_list_nodes]
        node_list = ml_client.compute.list_nodes(name="cpu-cluster")
        # [END compute_operations_list_nodes]

    @handle_resource_exists_error
    def ml_compute_config_setup_2(self):
        # [START compute_operations_create_update]
        from azure.ai.ml.entities import AmlCompute

        compute_obj = AmlCompute(
            name=compute_name_1,
            tags={"key1": "value1", "key2": "value2"},
            min_instances=0,
            max_instances=10,
            idle_time_before_scale_down=100,
        )
        registered_compute = ml_client.compute.begin_create_or_update(compute_obj)
        # [END compute_operations_create_update]

    @handle_resource_exists_error
    def ml_compute_config_setup_3(self):
        # [START compute_operations_attach]
        from azure.ai.ml.entities import AmlCompute

        compute_obj = AmlCompute(
            name=compute_name_2,
            tags={"key1": "value1", "key2": "value2"},
            min_instances=0,
            max_instances=10,
            idle_time_before_scale_down=100,
        )
        attached_compute = ml_client.compute.begin_attach(compute_obj)
        # [END compute_operations_attach]

        # [START compute_operations_update]
        compute_obj = ml_client.compute.get("cpu-cluster")
        compute_obj.idle_time_before_scale_down = 200
        updated_compute = ml_client.compute.begin_update(compute_obj)
        # [END compute_operations_update]

        # [START compute_operations_list_usage]
        usage_list = ml_client.compute.list_usage()
        # [END compute_operations_list_usage]

        # [START compute_operations_list_sizes]
        size_list = ml_client.compute.list_sizes()
        # [END compute_operations_list_sizes]

        # [START amlcompute]
        from azure.ai.ml.entities import AmlCompute, IdentityConfiguration, ManagedIdentityConfiguration

        aml_compute = AmlCompute(
            name="my-aml-compute",
            min_instances=0,
            max_instances=10,
            idle_time_before_scale_down=100,
            identity=IdentityConfiguration(
                type="UserAssigned",
                user_assigned_identities=[
                    ManagedIdentityConfiguration(
                        resource_id="/subscriptions/1234567-abcd-ef12-1234-12345/resourcegroups/our_rg_eastus/providers/Microsoft.ManagedIdentity/userAssignedIdentities/our-agent-aks"
                    )
                ],
            ),
        )
        # [END amlcompute]

        # [START aml_compute_ssh_settings]
        from azure.ai.ml.entities import AmlComputeSshSettings

        ssh_settings = AmlComputeSshSettings(
            admin_username="azureuser",
            ssh_key_value="ssh-rsa ABCDEFGHIJKLMNOPQRSTUVWXYZ administrator@MININT-2023",
            admin_password="password123",
        )
        # [END aml_compute_ssh_settings]

        # [START compute_instance_ssh_settings]
        from azure.ai.ml.entities import ComputeInstanceSshSettings

        ssh_settings = ComputeInstanceSshSettings(  # type:ignore
            ssh_key_value="ssh-rsa ABCDEFGHIJKLMNOPQRSTUVWXYZ administrator@MININT-2023"
        )
        # [END compute_instance_ssh_settings]

        # [START assigned_user_configuration]
        from azure.ai.ml.entities import AssignedUserConfiguration

        on_behalf_of_config = AssignedUserConfiguration(user_tenant_id="12345", user_object_id="abcdef")
        # [END assigned_user_configuration]

        # [START compute_operations_stop]
        ml_client.compute.begin_stop(ci_name)
        # [END compute_operations_stop]

        # [START compute_operations_start]
        ml_client.compute.begin_start(ci_name)
        # [END compute_operations_start]

        # [START vm_ssh_settings]
        from azure.ai.ml.entities import VirtualMachineSshSettings

        ssh_settings = VirtualMachineSshSettings(  # type:ignore
            admin_username="azureuser",
            admin_password="azureuserpassword",
            ssh_port=8888,
            ssh_private_key_file="../tests/test_configs/compute/ssh_fake_key.txt",
        )
        # [END vm_ssh_settings]

        # [START vm_compute]
        from azure.ai.ml.entities import VirtualMachineCompute

        vm_compute = VirtualMachineCompute(
            name="vm-compute",
            resource_id="/subscriptions/123456-1234-1234-1234-123456789/resourceGroups/my-rg/providers/Microsoft.Compute/virtualMachines/my-vm",
            ssh_settings=ssh_settings,  # type:ignore
        )
        # [END vm_compute]

        # [START network_settings]
        from azure.ai.ml.entities import (
            AmlCompute,
            IdentityConfiguration,
            ManagedIdentityConfiguration,
            NetworkSettings,
        )

        aml_compute = AmlCompute(
            name="my-compute",
            min_instances=0,
            max_instances=10,
            idle_time_before_scale_down=100,
            network_settings=NetworkSettings(vnet_name="my-vnet", subnet="default"),
        )
        # [END network_settings]

        # [START compute_runtime]
        from azure.ai.ml.entities import ComputeRuntime

        compute_runtime = ComputeRuntime(spark_runtime_version="3.4.0")
        # [END compute_runtime]

        # [START compute_start_stop_schedule]
        from azure.ai.ml.constants import TimeZone
        from azure.ai.ml.entities import ComputeSchedules, ComputeStartStopSchedule, CronTrigger

        start_stop = ComputeStartStopSchedule(
            trigger=CronTrigger(
                expression="15 10 * * 1",
                start_time="2022-03-10 10:15:00",
                end_time="2022-06-10 10:15:00",
                time_zone=TimeZone.PACIFIC_STANDARD_TIME,
            )
        )
        compute_schedules = ComputeSchedules(compute_start_stop=[start_stop])

        # [END compute_start_stop_schedule]

        # [START image_metadata]
        from azure.ai.ml.entities import ImageMetadata

        os_image_metadata = ImageMetadata(
            current_image_version="22.08.19",
            latest_image_version="22.08.20",
            is_latest_os_image_version=False,
        )
        # [END image_metadata]

        # [START kubernetes_compute]
        from azure.ai.ml.entities import KubernetesCompute

        k8s_compute = KubernetesCompute(
            identity=IdentityConfiguration(
                type="UserAssigned",
                user_assigned_identities=[
                    ManagedIdentityConfiguration(
                        resource_id="/subscriptions/1234567-abcd-ef12-1234-12345/resourcegroups/our_rg_eastus/providers/Microsoft.ManagedIdentity/userAssignedIdentities/our-agent-aks"
                    )
                ],
            ),
        )
        # [END kubernetes_compute]

        # [START materialization_compute_resource]
        from azure.ai.ml.entities import MaterializationComputeResource

        materialization_compute = MaterializationComputeResource(instance_type="standard_e4s_v3")
        # [END materialization_compute_resource]

        # [START compute_operations_restart]
        ml_client.compute.begin_restart(ci_name)
        # [END compute_operations_restart]

        # [START compute_operations_delete]
        ml_client.compute.begin_delete(compute_name_1, action="Detach")

        ml_client.compute.begin_delete(compute_name_2)
        # [END compute_operations_delete]


if __name__ == "__main__":
    sample = ComputeConfigurationOptions()
    sample.ml_compute_config_setup_0()
    sample.ml_compute_config_setup_1()
    sample.ml_compute_config_setup_2()
    sample.ml_compute_config_setup_3()



# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

from marshmallow import ValidationError, fields, post_load, validates_schema

from azure.ai.ml._schema.core.schema import PathAwareSchema
from azure.ai.ml.entities._workspace.network_acls import DefaultActionType, IPRule, NetworkAcls


class IPRuleSchema(PathAwareSchema):
    """Schema for IPRule."""

    value = fields.Str(required=True)

    @post_load
    def make(self, data, **kwargs):  # pylint: disable=unused-argument
        """Create an IPRule object from the marshmallow schema.

        :param data: The data from which the IPRule is being loaded.
        :type data: OrderedDict[str, Any]
        :returns: An IPRule object.
        :rtype: azure.ai.ml.entities._workspace.network_acls.NetworkAcls.IPRule
        """
        return IPRule(**data)


class NetworkAclsSchema(PathAwareSchema):
    """Schema for NetworkAcls.

    :param default_action: Specifies the default action when no IP rules are matched.
    :type default_action: str
    :param ip_rules: Rules governing the accessibility of a resource from a specific IP address or IP range.
    :type ip_rules: Optional[List[IPRule]]
    """

    default_action = fields.Str(required=True)
    ip_rules = fields.List(fields.Nested(IPRuleSchema), allow_none=True)

    @post_load
    def make(self, data, **kwargs):  # pylint: disable=unused-argument
        """Create a NetworkAcls object from the marshmallow schema.

        :param data: The data from which the NetworkAcls is being loaded.
        :type data: OrderedDict[str, Any]
        :returns: A NetworkAcls object.
        :rtype: azure.ai.ml.entities._workspace.network_acls.NetworkAcls
        """
        return NetworkAcls(**data)

    @validates_schema
    def validate_schema(self, data, **kwargs):  # pylint: disable=unused-argument
        """Validate the NetworkAcls schema.

        :param data: The data to validate.
        :type data: OrderedDict[str, Any]
        :raises ValidationError: If the schema is invalid.
        """
        if data["default_action"] not in set([DefaultActionType.DENY, DefaultActionType.ALLOW]):
            raise ValidationError("Invalid value for default_action. Must be 'Deny' or 'Allow'.")

        if data["default_action"] == DefaultActionType.DENY and not data.get("ip_rules"):
            raise ValidationError("ip_rules must be provided when default_action is 'Deny'.")



# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

# pylint: disable=protected-access

import os
from typing import Any, Callable, Dict, List, Optional, Tuple, Union

from azure.ai.ml.constants._common import AssetTypes, LegacyAssetTypes
from azure.ai.ml.constants._component import ComponentSource
from azure.ai.ml.entities._assets.environment import Environment
from azure.ai.ml.entities._component.command_component import CommandComponent
from azure.ai.ml.entities._credentials import (
    AmlTokenConfiguration,
    ManagedIdentityConfiguration,
    UserIdentityConfiguration,
)
from azure.ai.ml.entities._inputs_outputs import Input, Output
from azure.ai.ml.entities._job.distribution import (
    DistributionConfiguration,
    MpiDistribution,
    PyTorchDistribution,
    RayDistribution,
    TensorFlowDistribution,
)
from azure.ai.ml.entities._job.job_service import (
    JobService,
    JupyterLabJobService,
    SshJobService,
    TensorBoardJobService,
    VsCodeJobService,
)
from azure.ai.ml.entities._job.pipeline._component_translatable import ComponentTranslatableMixin
from azure.ai.ml.entities._job.sweep.search_space import SweepDistribution
from azure.ai.ml.exceptions import ErrorTarget, ValidationErrorType, ValidationException

from .command import Command

SUPPORTED_INPUTS = [
    LegacyAssetTypes.PATH,
    AssetTypes.URI_FILE,
    AssetTypes.URI_FOLDER,
    AssetTypes.CUSTOM_MODEL,
    AssetTypes.MLFLOW_MODEL,
    AssetTypes.MLTABLE,
    AssetTypes.TRITON_MODEL,
]


def _parse_input(input_value: Union[Input, Dict, SweepDistribution, str, bool, int, float]) -> Tuple:
    component_input = None
    job_input: Optional[Union[Input, Dict, SweepDistribution, str, bool, int, float]] = None

    if isinstance(input_value, Input):
        component_input = Input(**input_value._to_dict())
        input_type = input_value.type
        if input_type in SUPPORTED_INPUTS:
            job_input = Input(**input_value._to_dict())
    elif isinstance(input_value, dict):
        # if user provided dict, we try to parse it to Input.
        # for job input, only parse for path type
        input_type = input_value.get("type", None)
        if input_type in SUPPORTED_INPUTS:
            job_input = Input(**input_value)
        component_input = Input(**input_value)
    elif isinstance(input_value, (SweepDistribution, str, bool, int, float)):
        # Input bindings are not supported
        component_input = ComponentTranslatableMixin._to_input_builder_function(input_value)
        job_input = input_value
    else:
        msg = f"Unsupported input type: {type(input_value)}"
        msg += ", only Input, dict, str, bool, int and float are supported."
        raise ValidationException(
            message=msg,
            no_personal_data_message=msg,
            target=ErrorTarget.JOB,
            error_type=ValidationErrorType.INVALID_VALUE,
        )
    return component_input, job_input


def _parse_output(output_value: Optional[Union[Output, Dict, str]]) -> Tuple:
    component_output = None
    job_output: Optional[Union[Output, Dict, str]] = None

    if isinstance(output_value, Output):
        component_output = Output(**output_value._to_dict())
        job_output = Output(**output_value._to_dict())
    elif not output_value:
        # output value can be None or empty dictionary
        # None output value will be packed into a JobOutput object with mode = ReadWriteMount & type = UriFolder
        component_output = ComponentTranslatableMixin._to_output(output_value)
        job_output = output_value
    elif isinstance(output_value, dict):  # When output value is a non-empty dictionary
        job_output = Output(**output_value)
        component_output = Output(**output_value)
    elif isinstance(output_value, str):  # When output is passed in from pipeline job yaml
        job_output = output_value
    else:
        msg = f"Unsupported output type: {type(output_value)}, only Output and dict are supported."
        raise ValidationException(
            message=msg,
            no_personal_data_message=msg,
            target=ErrorTarget.JOB,
            error_type=ValidationErrorType.INVALID_VALUE,
        )
    return component_output, job_output


def _parse_inputs_outputs(io_dict: Dict, parse_func: Callable) -> Tuple[Dict, Dict]:
    component_io_dict, job_io_dict = {}, {}
    if io_dict:
        for key, val in io_dict.items():
            component_io, job_io = parse_func(val)
            component_io_dict[key] = component_io
            job_io_dict[key] = job_io
    return component_io_dict, job_io_dict


def command(
    *,
    name: Optional[str] = None,
    description: Optional[str] = None,
    tags: Optional[Dict] = None,
    properties: Optional[Dict] = None,
    display_name: Optional[str] = None,
    command: Optional[str] = None,  # pylint: disable=redefined-outer-name
    experiment_name: Optional[str] = None,
    environment: Optional[Union[str, Environment]] = None,
    environment_variables: Optional[Dict] = None,
    distribution: Optional[
        Union[
            Dict,
            MpiDistribution,
            TensorFlowDistribution,
            PyTorchDistribution,
            RayDistribution,
            DistributionConfiguration,
        ]
    ] = None,
    compute: Optional[str] = None,
    inputs: Optional[Dict] = None,
    outputs: Optional[Dict] = None,
    instance_count: Optional[int] = None,
    instance_type: Optional[str] = None,
    locations: Optional[List[str]] = None,
    docker_args: Optional[Union[str, List[str]]] = None,
    shm_size: Optional[str] = None,
    timeout: Optional[int] = None,
    code: Optional[Union[str, os.PathLike]] = None,
    identity: Optional[Union[ManagedIdentityConfiguration, AmlTokenConfiguration, UserIdentityConfiguration]] = None,
    is_deterministic: bool = True,
    services: Optional[
        Dict[str, Union[JobService, JupyterLabJobService, SshJobService, TensorBoardJobService, VsCodeJobService]]
    ] = None,
    job_tier: Optional[str] = None,
    priority: Optional[str] = None,
    parent_job_name: Optional[str] = None,
    **kwargs: Any,
) -> Command:
    """Creates a Command object which can be used inside a dsl.pipeline function or used as a standalone Command job.

    :keyword name: The name of the Command job or component.
    :paramtype name: Optional[str]
    :keyword description: The description of the Command. Defaults to None.
    :paramtype description: Optional[str]
    :keyword tags: Tag dictionary. Tags can be added, removed, and updated. Defaults to None.
    :paramtype tags: Optional[dict[str, str]]
    :keyword properties: The job property dictionary. Defaults to None.
    :paramtype properties: Optional[dict[str, str]]
    :keyword display_name: The display name of the job. Defaults to a randomly generated name.
    :paramtype display_name: Optional[str]
    :keyword command: The command to be executed. Defaults to None.
    :paramtype command: Optional[str]
    :keyword experiment_name: The name of the experiment that the job will be created under. Defaults to current
        directory name.
    :paramtype experiment_name: Optional[str]
    :keyword environment: The environment that the job will run in.
    :paramtype environment: Optional[Union[str, ~azure.ai.ml.entities.Environment]]
    :keyword environment_variables: A dictionary of environment variable names and values.
        These environment variables are set on the process where user script is being executed.
        Defaults to None.
    :paramtype environment_variables: Optional[dict[str, str]]
    :keyword distribution: The configuration for distributed jobs. Defaults to None.
    :paramtype distribution: Optional[Union[dict, ~azure.ai.ml.PyTorchDistribution, ~azure.ai.ml.MpiDistribution,
        ~azure.ai.ml.TensorFlowDistribution, ~azure.ai.ml.RayDistribution]]
    :keyword compute: The compute target the job will run on. Defaults to default compute.
    :paramtype compute: Optional[str]
    :keyword inputs: A mapping of input names to input data sources used in the job. Defaults to None.
    :paramtype inputs: Optional[dict[str, Union[~azure.ai.ml.Input, str, bool, int, float, Enum]]]
    :keyword outputs: A mapping of output names to output data sources used in the job. Defaults to None.
    :paramtype outputs: Optional[dict[str, Union[str, ~azure.ai.ml.Output]]]
    :keyword instance_count: The number of instances or nodes to be used by the compute target. Defaults to 1.
    :paramtype instance_count: Optional[int]
    :keyword instance_type: The type of VM to be used by the compute target.
    :paramtype instance_type: Optional[str]
    :keyword locations: The list of locations where the job will run.
    :paramtype locations: Optional[List[str]]
    :keyword docker_args: Extra arguments to pass to the Docker run command. This would override any
        parameters that have already been set by the system, or in this section. This parameter is only
        supported for Azure ML compute types. Defaults to None.
    :paramtype docker_args: Optional[Union[str,List[str]]]
    :keyword shm_size: The size of the Docker container's shared memory block. This should be in the
        format of (number)(unit) where the number has to be greater than 0 and the unit can be one of
        b(bytes), k(kilobytes), m(megabytes), or g(gigabytes).
    :paramtype shm_size: Optional[str]
    :keyword timeout: The number, in seconds, after which the job will be cancelled.
    :paramtype timeout: Optional[int]
    :keyword code: The source code to run the job. Can be a local path or "http:", "https:", or "azureml:" url
        pointing to a remote location.
    :paramtype code: Optional[Union[str, os.PathLike]]
    :keyword identity: The identity that the command job will use while running on compute.
    :paramtype identity: Optional[Union[
        ~azure.ai.ml.entities.ManagedIdentityConfiguration,
        ~azure.ai.ml.entities.AmlTokenConfiguration,
        ~azure.ai.ml.entities.UserIdentityConfiguration]]
    :keyword is_deterministic: Specifies whether the Command will return the same output given the same input.
        Defaults to True. When True, if a Command Component is deterministic and has been run before in the
        current workspace with the same input and settings, it will reuse results from a previously submitted
        job when used as a node or step in a pipeline. In that scenario, no compute resources will be used.
    :paramtype is_deterministic: bool
    :keyword services: The interactive services for the node. Defaults to None. This is an experimental parameter,
        and may change at any time. Please see https://aka.ms/azuremlexperimental for more information.
    :paramtype services: Optional[dict[str, Union[~azure.ai.ml.entities.JobService,
        ~azure.ai.ml.entities.JupyterLabJobService, ~azure.ai.ml.entities.SshJobService,
        ~azure.ai.ml.entities.TensorBoardJobService, ~azure.ai.ml.entities.VsCodeJobService]]]
    :keyword job_tier: The job tier. Accepted values are "Spot", "Basic", "Standard", or "Premium".
    :paramtype job_tier: Optional[str]
    :keyword priority: The priority of the job on the compute. Accepted values are "low", "medium", and "high".
        Defaults to "medium".
    :paramtype priority: Optional[str]
    :keyword parent_job_name: parent job id for command job
    :paramtype parent_job_name: Optional[str]
    :return: A Command object.
    :rtype: ~azure.ai.ml.entities.Command

    .. admonition:: Example:

        .. literalinclude:: ../samples/ml_samples_command_configurations.py
            :start-after: [START command_function]
            :end-before: [END command_function]
            :language: python
            :dedent: 8
            :caption: Creating a Command Job using the command() builder method.
    """
    # pylint: disable=too-many-locals
    inputs = inputs or {}
    outputs = outputs or {}
    component_inputs, job_inputs = _parse_inputs_outputs(inputs, parse_func=_parse_input)
    # job inputs can not be None
    job_inputs = {k: v for k, v in job_inputs.items() if v is not None}
    component_outputs, job_outputs = _parse_inputs_outputs(outputs, parse_func=_parse_output)

    component = kwargs.pop("component", None)
    if component is None:
        component = CommandComponent(
            name=name,
            tags=tags,
            code=code,
            command=command,
            environment=environment,
            display_name=display_name,
            description=description,
            inputs=component_inputs,
            outputs=component_outputs,
            distribution=distribution,
            environment_variables=environment_variables,
            _source=ComponentSource.BUILDER,
            is_deterministic=is_deterministic,
            **kwargs,
        )
    command_obj = Command(
        component=component,
        name=name,
        description=description,
        tags=tags,
        properties=properties,
        display_name=display_name,
        experiment_name=experiment_name,
        compute=compute,
        inputs=job_inputs,
        outputs=job_outputs,
        identity=identity,
        distribution=distribution,
        environment=environment,
        environment_variables=environment_variables,
        services=services,
        parent_job_name=parent_job_name,
        **kwargs,
    )

    if (
        locations is not None
        or instance_count is not None
        or instance_type is not None
        or docker_args is not None
        or shm_size is not None
    ):
        command_obj.set_resources(
            locations=locations,
            instance_count=instance_count,
            instance_type=instance_type,
            docker_args=docker_args,
            shm_size=shm_size,
        )

    if timeout is not None:
        command_obj.set_limits(timeout=timeout)

    if job_tier is not None or priority is not None:
        command_obj.set_queue_settings(job_tier=job_tier, priority=priority)

    return command_obj



# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
import os
from unittest.mock import patch

import pytest

from azure.ai.ml import Input, Output, command, dsl, load_component, load_job
from azure.ai.ml.constants._common import AZUREML_PRIVATE_FEATURES_ENV_VAR
from azure.ai.ml.entities import CommandComponent, CommandJob, CommandJobLimits, JobResourceConfiguration

from .._util import _UTILS_TIMEOUT_SECOND


@pytest.mark.timeout(_UTILS_TIMEOUT_SECOND)
@pytest.mark.unittest
@pytest.mark.core_sdk_test
class TestTelemetryValue:
    def test_component_node_telemetry_value(self):
        # From yaml
        component_func = load_component("./tests/test_configs/components/helloworld_component.yml")
        v = component_func._get_telemetry_values()
        assert v["type"] == "command"
        assert v["source"] == "YAML.COMPONENT"
        assert v["is_anonymous"] is False
        component = component_func()
        v = component._get_telemetry_values()
        assert v["type"] == "command"
        assert v["source"] == "YAML.COMPONENT"

        # From class
        code = (
            "/subscriptions/4faaaf21-663f-4391-96fd-47197c630979/resourceGroups/"
            "test-rg-centraluseuap-v2-2021W10/providers/Microsoft.MachineLearningServices/"
            "workspaces/sdk_vnext_cli/codes/e736692c-8542-11eb-b746-6c2b59f8af4d/versions/1"
        )
        component = CommandComponent(
            name="sample_command_component_basic",
            display_name="CommandComponentBasic",
            description="This is the basic command component",
            tags={"tag": "tagvalue", "owner": "sdkteam"},
            version="1",
            outputs={"component_out_path": {"type": "uri_folder"}},
            command="echo Hello World",
            code=code,
            environment="AzureML-sklearn-1.0-ubuntu20.04-py38-cpu:33",
        )
        v = component._get_telemetry_values()
        assert v["type"] == "command"
        assert v["source"] == "CLASS"
        assert v["is_anonymous"] is False

        # From builder
        test_command = command(
            name="my-job",
            display_name="my-fancy-job",
            description="This is a fancy job",
            tags=dict(),
            command="python train.py --input-data ${{inputs.input_data}} --lr ${{inputs.learning_rate}}",
            code="./src",
            compute="cpu-cluster",
            environment="my-env:1",
            environment_variables=dict(foo="bar"),
            # Customers can still do this:
            resources=JobResourceConfiguration(instance_count=2, instance_type="STANDARD_D2"),
            limits=CommandJobLimits(timeout=300),
            inputs={
                "float": 0.01,
                "integer": 1,
                "string": "str",
                "boolean": False,
                "uri_folder": Input(type="uri_folder", path="https://my-blob/path/to/data", mode="ro_mount"),
                "uri_file": dict(type="uri_file", path="https://my-blob/path/to/data", mode="download"),
            },
            outputs={"my_model": Output(type="mlflow_model", mode="rw_mount")},
        )
        v = test_command._get_telemetry_values()
        assert v["type"] == "command"
        assert v["source"] == "BUILDER"

    def test_pipeline_telemetry_value(self):
        # standalone command job
        basic_job = CommandJob(
            display_name="hello-world-job",
            command='echo "hello world"',
            environment="AzureML-Minimal:1",
            compute="cpu-cluster",
        )
        v = basic_job._get_telemetry_values()
        assert v["type"] == "command"

        # pipeline job
        test_path = "./tests/test_configs/pipeline_jobs/jobs_with_automl_nodes/onejob_automl_classification.yml"
        job = load_job(test_path)
        v = job._get_telemetry_values()
        assert v["type"] == "pipeline"
        assert v["source"] == "YAML.JOB"
        assert v["node_count"] == 1
        assert v["node_type"] == '{"automl": 1}'
        assert v["node_source"] == '{"BUILDER": 1}'

    def test_dsl_pipeline_telemetry_value(self):
        path = "./tests/test_configs/components/helloworld_component.yml"

        @dsl.pipeline()
        def pipeline_no_arg():
            component_func = load_component(path)
            component_func(component_in_path=Input(path="/a/path/on/ds"), component_in_number=1)

        pipeline1 = pipeline_no_arg()
        v = pipeline1._get_telemetry_values()
        assert v["type"] == "pipeline"
        assert v["source"] == "DSL"
        assert v["node_count"] == 1
        assert v["node_type"] == '{"command": 1}'
        assert v["node_source"] == '{"YAML.COMPONENT": 1}'

    @patch.dict(os.environ, {AZUREML_PRIVATE_FEATURES_ENV_VAR: "True"})
    def test_dsl_subpipeline_telemetry_value(self):
        path = "./tests/test_configs/components/helloworld_component.yml"
        component_func1 = load_component(path)

        @dsl.pipeline(name="sub_pipeline")
        def sub_pipeline(component_in_number: int, component_in_path: str):
            node1 = component_func1(component_in_number=component_in_number, component_in_path=component_in_path)
            node2 = component_func1(
                component_in_number=component_in_number, component_in_path=node1.outputs.component_out_path
            )
            return {"sub_pipeline_out": node2.outputs.component_out_path}

        @dsl.pipeline(name="root_pipeline")
        def root_pipeline(component_in_number: int, component_in_path: str):
            node1 = sub_pipeline(component_in_number=component_in_number, component_in_path=component_in_path)
            node1.compute = "will be ignored"
            node2 = sub_pipeline(
                component_in_number=component_in_number, component_in_path=node1.outputs.sub_pipeline_out
            )
            return node2.outputs

        pipeline1 = root_pipeline(1, "test")
        v = pipeline1._get_telemetry_values()
        assert v["type"] == "pipeline"
        assert v["source"] == "DSL"
        assert v["node_count"] == 2
        assert v["node_type"] == '{"pipeline": 2}'
        assert v["node_source"] == '{"DSL": 2}'
